%define name    autofs
%define version 5.0.7
%define release %mkrel 1

Name:           %{name}
Version:        %{version}
Release:        %{release}
License:        GPL
Summary:        A tool for automatically mounting and unmounting filesystems
Group:          System/Kernel and hardware
URL:            ftp://ftp.kernel.org/pub/linux/daemons/autofs
Source0:        ftp://ftp.kernel.org/pub/linux/daemons/autofs/v5/autofs-%{version}.tar.xz
Source1:        %{name}.init
Patch0:         autofs-5.0.4-link-with-kerberos-lib.patch
Patch1:         autofs-5.0.6-separate-config-files.patch
Patch2:         autofs-5.0.4-rename-configuration-file.patch
Patch3:		autofs-5.0.7-after-nss-lookup.patch
Requires(post): rpm-helper
Requires(preun):rpm-helper
BuildRequires:  openldap-devel
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  libsasl-devel
BuildRequires:  krb-devel
BuildRequires:  libxml2-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}

%description
autofs is a daemon which automatically mounts filesystems when you use
them, and unmounts them later when you are not using them.  This can
include network filesystems, CD-ROMs, floppies, and so forth.

%prep
%setup -q -n %{name}-%{version}
%patch0 -p 1
%patch1 -p 1
%patch2 -p 1
%patch3 -p 1

%build
autoreconf
%serverbuild
%configure2_5x --with-mapdir=%{_sysconfdir}/%{name} \
           --with-confdir=%{_sysconfdir}/%{name} \
           --with-sasl=yes
           
           
%make DONTSTRIP=1

mkdir examples
cp samples/ldap* examples
cp samples/autofs.schema examples

rm -f README.gentoo

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_libdir}/autofs
mkdir -p %{buildroot}%{_mandir}/{man5,man8}
mkdir -p %{buildroot}%{_sysconfdir}

%make install INSTALLROOT=%{buildroot}

install -d -m 755 %{buildroot}%{_initrddir}
install -m 755 %{SOURCE1} %{buildroot}%{_initrddir}/%{name}

rm -f %{buildroot}%{_sysconfdir}/init.d/%{name}
rm -f %{buildroot}%{_mandir}/man8/autofs*

cat > README.pclos <<EOF
RPM specific notes

setup
-----
Configuration handling in this package differs from upstream one on several points:
- the automounts daemon configuration file is %{_sysconfdir}/autofs/autofs.conf
- the autofs service configuration file is %{_sysconfdir}/sysconfig/autofs
- the configuration directives in %{_sysconfdir}/autofs/autofs.conf don't have
  the 'DEFAULT_' prefix (for instance, DEFAULT_TIMEOUT is just TIMEOUT). This
  has recently been changed upstream in version 5.0.2 too, but given than 
  documentation still refers to old names

Upgrade
-------
Map files have been moved from %{_sysconfdir} to %{_sysconfdir}/autofs. Upgrade
procedure should handle the change automatically.
LDAP usage has changed between autofs 4 and 5. The LDAP schema used has now to
be configured explicitely in autofs configuration, so as to avoid useless
queries. As this can't be handled by package upgrade procedure, you'll have to
edit your configuration manually. See auto.master(5) for details.

EOF

%pre
if [ $1 != "0" ]; then
    # upgrade
    if [ ! -d %{_sysconfdir}/autofs ]; then
        # 4 -> 5 upgrade
        mkdir %{_sysconfdir}/autofs
        for file in %{_sysconfdir}/auto.{master,misc,net,smb}; do
            if [ -f "$file" ]; then
                mv $file* %{_sysconfdir}/autofs
            fi
        done
    fi
fi

%post
%_post_service autofs

%preun
%_preun_service autofs

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc INSTALL CHANGELOG CREDITS README* examples
%config(noreplace) %{_sysconfdir}/autofs
%config(noreplace) %{_sysconfdir}/sysconfig/autofs
%{_initrddir}/%{name}
%{_libdir}/%{name}
%{_sbindir}/automount
%{_mandir}/*/*


%changelog
* Wed Jun 26 2013 Texstar <texstar at gmail.com> 5.0.7-1pclos2013
- update

* Fri Sep 10 2010 Texstar <texstar at gmail.com> 5.0.5-2pclos2010
- rebuild ldap

* Fri May 21 2010 slick50 <lxgator@gmail.com> 5.0.5-1pclos2010
- 5.0.5

* Sat Aug 09 2008 Gettinther <gettinther@gmail.com> 5.0.3-1pclos2007
- 5.0.3
- no dependency on nfs-utils in package (automount is not nfs-specific)
- no dependency on nfs-common in initscript (automound doesn't requires it)
- update to latest official patch set
- fix init script dependencies
- fix parsing mount options with LDAP mounts (upstream patch)
- workaround upstream ldap-page-control check by adding -lpthread
- add upstream ldap-page-control-configure-fix patch
- rediff comment-default-master-map patch
- remove upstream 5.0.2 patches

* Tue Jan 29 2008 Texstar <texstar@gmail.com> 5.0.2-2pclos2007
- Security Update

* Sun Dec 16 2007 Texstar <texstar@gmail.com> 5.0.2-1pclos2007
- 5.0.2
